@@ -12,6 +12,8 @@ from peewee import (AutoField, BigAutoField, BigIntegerField, CharField,
                     DeferredThroughModel, DoubleField, FloatField,
                     ForeignKeyField, IntegerField, ManyToManyField, TextField)
 
+from playhouse.postgres_ext import ArrayField
+
 from sdssdb.exceptions import SdssdbUserWarning
 
 from .. import BaseModel
@@ -238,6 +240,14 @@ class SDSS_DR14_QSO(CatalogdbModel):
         table_name = 'sdss_dr14_qso'
 
 
+class SDSS_DR16_QSO(SDSS_DR14_QSO):
+
+    psfmag = ArrayField(field_class=FloatField, null=True)
+
+    class Meta:
+        table_name = 'sdss_dr16_qso'
+
+
 class unWISE(CatalogdbModel):
 
     unwise_objid = TextField(primary_key=True)
@@ -730,6 +740,48 @@ class SkyMapper_DR1_1(CatalogdbModel):
         table_name = 'skymapper_dr1_1'
 
 
+class SkyMapper_DR2(CatalogdbModel):
+
+    object_id = BigIntegerField(primary_key=True)
+
+    allwise = ForeignKeyField(AllWise, field='cntr',
+                              column_name='allwise_cntr',
+                              object_id_name='allwise_cntr',
+                              backref='skymapper_dr2')
+
+    gaia = ForeignKeyField(Gaia_DR2, field='source_id',
+                           column_name='gaia_dr2_id1',
+                           object_id_name='gaia_dr2_id1',
+                           backref='skymapper_dr2')
+
+    tic = ForeignKeyField(TIC_v8,
+                          field='gaia_int',
+                          column_name='gaia_dr2_id1',
+                          object_id_name='gaia_dr2_id1',
+                          backref='+')
+
+    @property
+    def twomass1(self):
+        """Returns the closest 2MASS PSC source, if defined."""
+
+        if self.twomass_cat1 != 'PSC':
+            return None
+
+        return TwoMassPSC.get(pts_key=self.twomass_key1)
+
+    @property
+    def twomass2(self):
+        """Returns the second closest 2MASS PSC source, if defined."""
+
+        if self.twomass_cat2 != 'PSC':
+            return None
+
+        return TwoMassPSC.get(pts_key=self.twomass_key2)
+
+    class Meta:
+        table_name = 'skymapper_dr2'
+
+
 class PS1_g18(CatalogdbModel):
 
     objid = BigIntegerField(primary_key=True)
@@ -738,6 +790,15 @@ class PS1_g18(CatalogdbModel):
         table_name = 'ps1_g18'
 
 
+# PS1_g18 above is a subset of Panstarrs1
+class Panstarrs1(CatalogdbModel):
+
+    catid_objid = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'panstarrs1'
+
+
 class GLIMPSE(CatalogdbModel):
 
     pk = BigIntegerField(primary_key=True)
@@ -751,6 +812,19 @@ class GLIMPSE(CatalogdbModel):
         print_fields = ['designation']
 
 
+class GLIMPSE360(CatalogdbModel):
+
+    pkey = BigIntegerField(primary_key=True)
+
+    twomass = ForeignKeyField(TwoMassPSC, field='pts_key',
+                              column_name='tmass_cntr',
+                              backref='glimpse360_targets')
+
+    class Meta:
+        table_name = 'glimpse360'
+        print_fields = ['designation']
+
+
 class BHM_eFEDS_Veto(CatalogdbModel):
 
     pk = BigIntegerField(primary_key=True)
@@ -1033,6 +1107,14 @@ class GAIA_ASSAS_SN_Cepheids(CatalogdbModel):
                            backref='assas')
 
 
+class Skies_v1(CatalogdbModel):
+
+    pix_32768 = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'skies_v1'
+
+
 _Gaia_DR2_TwoMass_Deferred.set_model(Gaia_DR2_TwoMass_Best_Neighbour)
 _APOGEE_Star_Visit_Deferred.set_model(SDSS_DR16_APOGEE_Star_AllVisit)
 
