@@ -173,10 +173,9 @@ class Carton(TargetdbBase):
 
 
 class Target(TargetdbBase):
-    catalog = ForeignKeyField(column_name='catalogid',
-                              object_id_name='catalogid',
-                              model=catalogdb.Catalog,
-                              field='catalogid')
+    catalogid = ForeignKeyField(column_name='catalogid',
+                                model=catalogdb.Catalog,
+                                field='catalogid')
     dec = DoubleField(null=True)
     epoch = FloatField(null=True)
     pk = AutoField()
@@ -234,6 +233,7 @@ class CartonToTarget(TargetdbBase):
                              field='pk',
                              on_delete='CASCADE')
     priority = IntegerField()
+    value = FloatField()
 
     class Meta:
         table_name = 'carton_to_target'
@@ -248,10 +248,10 @@ class Magnitude(TargetdbBase):
     pk = AutoField()
     r = FloatField(null=True)
     rp = FloatField(null=True)
-    target = ForeignKeyField(column_name='target_pk',
-                             field='pk',
-                             model=Target,
-                             backref='magnitudes')
+    carton_to_target = ForeignKeyField(column_name='carton_to_target_pk',
+                                       field='pk',
+                                       model=CartonToTarget,
+                                       backref='magnitudes')
 
     class Meta:
         table_name = 'magnitude'
